==> eslint-config-scalify-0.3.9.tgz: package/rules/errors.js <==
// possible Js errors

module.exports =
{
	rules:
	{

		// disallow assignment operators in conditional expressions
		'no-cond-assign': 'error',

		// disallow constant expressions in conditions
		'no-constant-condition': 'error',

		// disallow control characters in regular expressions
		'no-control-regex': 'off',

		// disallow the use of debugger
		'no-debugger': 'error',

		// disallow duplicate arguments in function definitions
		'no-dupe-args': 'error',

		// disallow duplicate keys in object literals
		'no-dupe-keys': 'error',

		// Rule to disallow a duplicate case label
		'no-duplicate-case': 'error',

		// disallow empty character classes in regular expressions
		'no-empty-character-class': 'off',

		// disallow empty block statements
		'no-empty': 'error',

		// disallow reassigning exceptions in catch clauses
		'no-ex-assign': 'error',

		// disallow unnecessary boolean casts
		'no-extra-boolean-cast': 'error',

		// disallow unnecessary parentheses
		'no-extra-parens': 'error',

		// disallow unnecessary semicolons
		'no-extra-semi': 'error',

		// disallow reassigning function declarations
		'no-func-assign': 'error',

		// disallow function or var declarations in nested blocks
		'no-inner-declarations': 'error',

		// disallow invalid regular expression strings in RegExp constructors
		'no-invalid-regexp': 'error',

		// disallow irregular whitespace outside of strings and comments
		'no-irregular-whitespace': 'error',

		// disallow calling global object properties as functions
		'no-obj-calls': 'error',

		// Disallow use of Object.prototypes builtins directly
		'no-prototype-builtins': 'error',

		// disallow multiple spaces in regular expressions
		'no-regex-spaces': 'off',

		// disallow sparse arrays
		'no-sparse-arrays': 'error',

		// disallow confusing multiline expressions
		'no-unexpected-multiline': 'error',

		// disallow unreachable code after return, throw, continue, and break statements
		'no-unreachable': 'error',

		// disallow control flow statements in finally blocks
		'no-unsafe-finally': 'error',

		// require calls to isNaN() when checking for NaN
		'use-isnan': 'error',

		// enforce valid JSDoc comments
		'valid-jsdoc': 'warn',

		// enforce comparing typeof expressions against valid strings
		'valid-typeof': 'error',

		// Enforce spacing before and after semicolons
		'semi-spacing': 'error',

		// require or disallow semicolons instead of ASI
		'semi': [ 'warn', 'always' ],

		// disallow spaces before semicolons
		'no-space-before-semi': 'off'
	}
};

==> eslint-config-scalify-0.4.3.tgz: package/rules/errors.js <==
// possible Js errors

module.exports =
{
	rules:
	{

		// disallow assignment operators in conditional expressions
		'no-cond-assign': 'error',

		// disallow constant expressions in conditions
		'no-constant-condition': 'error',

		// disallow control characters in regular expressions
		'no-control-regex': 'off',

		// disallow the use of debugger
		'no-debugger': 'error',

		// disallow duplicate arguments in function definitions
		'no-dupe-args': 'error',

		// disallow duplicate keys in object literals
		'no-dupe-keys': 'error',

		// Rule to disallow a duplicate case label
		'no-duplicate-case': 'error',

		// disallow empty character classes in regular expressions
		'no-empty-character-class': 'off',

		// disallow empty block statements
		'no-empty': 'error',

		// disallow reassigning exceptions in catch clauses
		'no-ex-assign': 'error',

		// disallow unnecessary boolean casts
		'no-extra-boolean-cast': 'error',

		// disallow unnecessary parentheses
		'no-extra-parens': 'off',

		// disallow unnecessary semicolons
		'no-extra-semi': 'error',

		// disallow reassigning function declarations
		'no-func-assign': 'error',

		// disallow function or var declarations in nested blocks
		'no-inner-declarations': 'error',

		// disallow invalid regular expression strings in RegExp constructors
		'no-invalid-regexp': 'error',

		// disallow irregular whitespace outside of strings and comments
		'no-irregular-whitespace': 'error',

		// disallow calling global object properties as functions
		'no-obj-calls': 'error',

		// Disallow use of Object.prototypes builtins directly
		'no-prototype-builtins': 'error',

		// disallow multiple spaces in regular expressions
		'no-regex-spaces': 'off',

		// disallow sparse arrays
		'no-sparse-arrays': 'error',

		// disallow confusing multiline expressions
		'no-unexpected-multiline': 'error',

		// disallow unreachable code after return, throw, continue, and break statements
		'no-unreachable': 'error',

		// disallow control flow statements in finally blocks
		'no-unsafe-finally': 'error',

		// require calls to isNaN() when checking for NaN
		'use-isnan': 'error',

		// enforce valid JSDoc comments
		'valid-jsdoc': 'warn',

		// enforce comparing typeof expressions against valid strings
		'valid-typeof': 'error',

		// Enforce spacing before and after semicolons
		'semi-spacing': 'error',

		// require or disallow semicolons instead of ASI
		'semi': [ 'warn', 'always' ],

		// disallow spaces before semicolons
		'no-space-before-semi': 'off'
	}
};
